package com.hw.dms.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import com.hw.common.security.utils.SecurityUtils;
import com.hw.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.dms.mapper.DmsBaseLubeStandardMapper;
import com.hw.dms.domain.DmsBaseLubeStandard;
import com.hw.dms.service.IDmsBaseLubeStandardService;

/**
 * 润滑标准信息Service业务层处理
 *
 * @author Open Platform
 * @date 2024-01-12
 */
@Service
public class DmsBaseLubeStandardServiceImpl implements IDmsBaseLubeStandardService
{
    @Autowired
    private DmsBaseLubeStandardMapper dmsBaseLubeStandardMapper;

    /**
     * 查询润滑标准信息
     *
     * @param lubeStandardId 润滑标准信息主键
     * @return 润滑标准信息
     */
    @Override
    public DmsBaseLubeStandard selectDmsBaseLubeStandardByLubeStandardId(Long lubeStandardId)
    {
        return dmsBaseLubeStandardMapper.selectDmsBaseLubeStandardByLubeStandardId(lubeStandardId);
    }

    /**
     * 查询润滑标准信息列表
     *
     * @param dmsBaseLubeStandard 润滑标准信息
     * @return 润滑标准信息
     */
    @Override
    public List<DmsBaseLubeStandard> selectDmsBaseLubeStandardList(DmsBaseLubeStandard dmsBaseLubeStandard)
    {
        return dmsBaseLubeStandardMapper.selectDmsBaseLubeStandardList(dmsBaseLubeStandard);
    }

    /**
     * 新增润滑标准信息
     *
     * @param dmsBaseLubeStandard 润滑标准信息
     * @return 结果
     */
    @Override
    public int insertDmsBaseLubeStandard(DmsBaseLubeStandard dmsBaseLubeStandard)
    {
        LoginUser user = SecurityUtils.getLoginUser();
        dmsBaseLubeStandard.setIsFlag("1");
        dmsBaseLubeStandard.setCreateBy(user.getUsername());
        dmsBaseLubeStandard.setCreateTime(DateUtils.getNowDate());
        return dmsBaseLubeStandardMapper.insertDmsBaseLubeStandard(dmsBaseLubeStandard);
    }

    /**
     * 修改润滑标准信息
     *
     * @param dmsBaseLubeStandard 润滑标准信息
     * @return 结果
     */
    @Override
    public int updateDmsBaseLubeStandard(DmsBaseLubeStandard dmsBaseLubeStandard)
    {

        LoginUser user = SecurityUtils.getLoginUser();
        dmsBaseLubeStandard.setUpdateBy(user.getUsername());
        dmsBaseLubeStandard.setUpdateTime(DateUtils.getNowDate());
        return dmsBaseLubeStandardMapper.updateDmsBaseLubeStandard(dmsBaseLubeStandard);
    }

    /**
     * 批量删除润滑标准信息
     *
     * @param lubeStandardIds 需要删除的润滑标准信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseLubeStandardByLubeStandardIds(Long[] lubeStandardIds)
    {
        return dmsBaseLubeStandardMapper.deleteDmsBaseLubeStandardByLubeStandardIds(lubeStandardIds);
    }

    /**
     * 删除润滑标准信息信息
     *
     * @param lubeStandardId 润滑标准信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseLubeStandardByLubeStandardId(Long lubeStandardId)
    {
        return dmsBaseLubeStandardMapper.deleteDmsBaseLubeStandardByLubeStandardId(lubeStandardId);
    }
}
